@@ -13,15 +13,6 @@
 #define dngettext(pkg, String, StringP, N) (N > 1 ? StringP : String)
 #endif
 
-#include <Rversion.h>
-#if !defined(R_VERSION) || R_VERSION < R_Version(3, 0, 0)
-# ifndef XLENGTH
-   // for  R <= 2.15.x :
-#  define XLENGTH(x) LENGTH(x)
-   typedef int R_xlen_t;
-# endif
-#endif
-
 
 
 /* --------- ./qn_sn.c : -------- */
